@@ -4,6 +4,7 @@ import networkx as nx
 from networkx.algorithms import bipartite
 import numpy as np
 import pandas as pd
+from tqdm import tqdm
 from .utils import Utils
 
 logger = logging.getLogger(__name__)
@@ -83,10 +84,12 @@ class Shared:
         ranked_shares_df['ct_shares_count']=shares_gb['id'].transform('nunique')
         ranked_shares_df['first_share_date'] = shares_gb['date'].transform('min')
         ranked_shares_df['rank'] = shares_gb['date'].rank(ascending=True, method='first')
+        #ranked_shares_df['perc_of_shares'] = ranked_shares_df['rank']/ranked_shares_df['ct_shares_count']
+        ranked_shares_df['perc_of_shares'] = shares_gb['date'].rank(ascending=True)
         ranked_shares_df['sec_from_first_share'] = (ranked_shares_df['date'] - ranked_shares_df['first_share_date']).dt.total_seconds()
-        ranked_shares_df['perc_of_shares'] = ranked_shares_df['rank']/ranked_shares_df['ct_shares_count']
         ranked_shares_df = ranked_shares_df.sort_values(by = 'expanded')
 
+        #find URLs with an unusual fast second share and keep the quickest
         filtered_ranked_df = ranked_shares_df[ranked_shares_df['rank']==2].copy(deep=True)
         filtered_ranked_df['sec_from_first_share'] = filtered_ranked_df.groupby('expanded')['sec_from_first_share'].transform('min')
         filtered_ranked_df = filtered_ranked_df[['expanded', 'sec_from_first_share']]
@@ -310,33 +313,35 @@ class Shared:
             data_list = []
             urls_count = urls_df.shape[0]
             i=0
-            for index, row in urls_df.iterrows():
-                i=i+1
-                logger.info(f"processing {i} of {urls_count}, url={row['URL']}")
-                summary_df = crowtangle_shares_df[crowtangle_shares_df['expanded'] == row['URL']].copy(deep=True)
-                if summary_df.groupby('account_url')['account_url'].nunique().shape[0]>1:
-                    summary_df['date'] = summary_df['date'].astype('datetime64[ns]')
-                    #summary_df['cut'] = pd.cut(summary_df['date'], int(coordination_interval))
-                    date_serie = summary_df['date'].astype('int64') // 10 ** 9
-                    max = date_serie.max()
-                    min = date_serie.min()
-                    div = (max-min)/coordination_interval + 1
-                    summary_df["cut"] = pd.cut(summary_df['date'],int(div)).apply(lambda x: x.left).astype('datetime64[ns]')
-                    cut_gb = summary_df.groupby('cut')
-                    summary_df.loc[:,'count'] = cut_gb['cut'].transform('count')
-                    #summary_df = summary_df[['cut', 'count']].copy(deep=True)
-                    # summary_df = summary_df.rename(columns = {'date': 'share_date'})
-                    summary_df.loc[:,'url'] = row['URL']
-                    summary_df.loc[:,'account_url'] = cut_gb['account_url'].transform(lambda x: [x.tolist()]*len(x))
-                    summary_df.loc[:,'share_date'] = cut_gb['date'].transform(lambda x: [x.tolist()]*len(x))
-                    summary_df = summary_df[['cut', 'count', 'account_url','share_date', 'url']]
-                    summary_df = summary_df[summary_df['count']>1]
-                    if summary_df.shape[0]>1:
-                        summary_df = summary_df.loc[summary_df.astype(str).drop_duplicates().index]
-                        #summary_df['account_url'] = [account_url] * summary_df.shape[0]
-                        #summary_df['share_date'] = [dates] * summary_df.shape[0]
 
-                        data_list.append(summary_df)
+            with tqdm(total=urls_df.shape[0]) as pbar:
+                for index, row in urls_df.iterrows():
+                    pbar.update(1)
+                    i=i+1
+                    logger.debug(f"processing {i} of {urls_count}, url={row['URL']}")
+                    summary_df = crowtangle_shares_df[crowtangle_shares_df['expanded'] == row['URL']].copy(deep=True)
+                    if summary_df.groupby('account_url')['account_url'].nunique().shape[0]>1:
+                        summary_df['date'] = summary_df['date'].astype('datetime64[ns]')
+                        #summary_df['cut'] = pd.cut(summary_df['date'], int(coordination_interval))
+                        date_serie = summary_df['date'].astype('int64') // 10 ** 9
+                        max = date_serie.max()
+                        min = date_serie.min()
+                        div = (max-min)/coordination_interval + 1
+                        summary_df["cut"] = pd.cut(summary_df['date'],int(div)).apply(lambda x: x.left).astype('datetime64[ns]')
+                        cut_gb = summary_df.groupby('cut')
+                        summary_df.loc[:,'count'] = cut_gb['cut'].transform('count')
+                        #summary_df = summary_df[['cut', 'count']].copy(deep=True)
+                        # summary_df = summary_df.rename(columns = {'date': 'share_date'})
+                        summary_df.loc[:,'url'] = row['URL']
+                        summary_df.loc[:,'account_url'] = cut_gb['account_url'].transform(lambda x: [x.tolist()]*len(x))
+                        summary_df.loc[:,'share_date'] = cut_gb['date'].transform(lambda x: [x.tolist()]*len(x))
+                        summary_df = summary_df[['cut', 'count', 'account_url','share_date', 'url']]
+                        summary_df = summary_df[summary_df['count']>1]
+                        if summary_df.shape[0]>1:
+                            summary_df = summary_df.loc[summary_df.astype(str).drop_duplicates().index]
+                            #summary_df['account_url'] = [account_url] * summary_df.shape[0]
+                            #summary_df['share_date'] = [dates] * summary_df.shape[0]
+                            data_list.append(summary_df)
 
             data_df = pd.concat(data_list)
             if data_df.shape[0] == 0:
